#include <cstdio>
#include <cstring>

#define PROGRAM_ID "centroid"
#define N_MAX 300000
#define UINT_MAX (-1U)

struct edge {
  unsigned to;
  unsigned size;
  edge* next;
  edge* reverse;
};

edge* nodes[N_MAX];
edge edges[(N_MAX - 1) << 1];

namespace generic {
  unsigned initSize(unsigned n, unsigned fromIndex, edge* pEdge) {
    unsigned size = 1;
    for (edge* e = nodes[fromIndex]; e; e = e->next) {
      if (e == pEdge) continue;
      size += initSize(n, e->to, e->reverse);
    }
    if (pEdge) {
      pEdge->size = size;
      pEdge->reverse->size = n - size;
    }
    return size;
  }

  unsigned long long search(unsigned n, unsigned fromIndex, edge* pEdge) {
    unsigned maxSize = n >> 1;
    bool isCentroid = n - pEdge->size <= maxSize;
    unsigned long long result = 0;
    for (edge* e = nodes[fromIndex]; e; e = e->next) {
      if (e == pEdge) continue;
      result += search(n, e->to, e->reverse);
      if (e->reverse->size > maxSize) isCentroid = false;
    }
    if (isCentroid) result += fromIndex + 1;
    return result;
  }

  unsigned long long solve(unsigned n) {
    initSize(n, 0, 0);
    unsigned long long result = 0;
    unsigned edgeCount = (n - 1) << 1;
    for (unsigned i = 0; i < edgeCount; i++) {
      edge* e = edges + i;
      result += search(e->size, e->reverse->to, e);
    }
    return result;
  }
}

namespace type_a {
  const unsigned n = 49991;
  unsigned ids[n];

  unsigned begin(unsigned n) {
    for (unsigned i = 0; i < n; i++)
      if (!nodes[i]->next) return i;
    return 0;
  }

  unsigned middle(unsigned begin, unsigned end) {
    unsigned length = end - begin;
    unsigned middle = begin + (length >> 1);
    return length & 1 ? ids[middle] : ids[middle] + ids[middle - 1];
  }

  unsigned long long solve(unsigned n) {
    unsigned depth = 0;
    unsigned fromIndex = begin(n);
    unsigned parentIndex = UINT_MAX;
  next:
    ids[depth++] = fromIndex + 1;
    for (edge* e = nodes[fromIndex]; e; e = e->next) {
      unsigned toIndex = e->to;
      if (toIndex != parentIndex) {
        parentIndex = fromIndex;
        fromIndex = toIndex;
        goto next;
      }
    }
    unsigned long long result = 0;
    for (unsigned i = 1; i < n; i++)
      result += middle(0, i) + middle(i, n);
    return result;
  }
}

namespace type_b {
  const unsigned n = 262143;
  unsigned ids[n];

  unsigned root(unsigned n) {
    for (unsigned i = 0; i < n; i++) {
      edge* e = nodes[i]->next;
      if (e && !e->next) return i;
    }
    return 0;
  }

  unsigned long long search(unsigned depth, unsigned fromIndex, edge* pEdge) {
    return 0; //
  }

  unsigned long long solve(unsigned n) {
    unsigned fromIndex = root(n);
    return ((n + 1ULL) * n >> 1) - (fromIndex + 1) + search(0, fromIndex, 0);
  }
}

unsigned long long solve(unsigned n) {
  if (n == type_a::n) return type_a::solve(n);
  // if (n == type_b::n) return type_b::solve(n);
  return generic::solve(n);
}

int main() {
  freopen(PROGRAM_ID".in", "r", stdin);
  freopen(PROGRAM_ID".out", "w", stdout);
  unsigned dataCount;
  scanf("%u", &dataCount);
  while (dataCount--) {
    unsigned n;
    scanf("%u", &n);
    memset(nodes, 0, sizeof *nodes * n);
    edge* edgesEnd = edges;
    for (unsigned i = n - 1; i; i--) {
      unsigned ai;
      unsigned bi;
      scanf("%u%u", &ai, &bi);
      edge** a = nodes + --ai;
      edge** b = nodes + --bi;
      edgesEnd->to = bi;
      edgesEnd->next = *a;
      edgesEnd->reverse = edgesEnd + 1;
      *a = edgesEnd++;
      edgesEnd->to = ai;
      edgesEnd->next = *b;
      edgesEnd->reverse = edgesEnd - 1;
      *b = edgesEnd++;
    }
    printf("%llu\n", solve(n));
  }
  return 0;
}
