#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <algorithm>
#include <cctype>
#include <vector>
#include <ctime>

inline int get_uint () {
  register char c = getchar();
  register int x = 0;
  while (!isdigit(c)) c = getchar();
  for (; isdigit(c); c = getchar()) x = (((x << 2) + x) << 1) + (c ^ 48);
  return x;
}

const int MAXN = 300000;

int n;

namespace DataStructure {
  struct Seg {
    int l, r, sum;
  } seg[MAXN * 50];
  int cnt = 0;
  inline void ensure(int &n) {
    if (!n) {
      n = ++cnt;
      seg[n].l = seg[n].r = seg[n].sum = 0;
    }
  }
  inline void seg_add(int &n, register int l, register int r, int p, int v) {
    ensure(n);
    register int x = n, mid;
    while (l != r) {
      Seg &m = seg[x];
      m.sum += v;
      mid = (l + r) >> 1;
      if (p <= mid) {
        r = mid;
        ensure(m.l);
        x = m.l;
      } else {
        l = mid + 1;
        ensure(m.r);
        x = m.r;
      }
    }
    seg[x].sum += v;
  }
  int seg_qry(int n, int l, int r, int L, int R) {
    if (!n) return 0;
    const Seg &m = seg[n];
    if (L == l && R == r) return m.sum;
    const int mid = (l + r) >> 1;
    if (R <= mid) return seg_qry(m.l, l, mid, L, R);
    if (L > mid) return seg_qry(m.r, mid + 1, r, L, R);
    return seg_qry(m.l, l, mid, L, mid) + seg_qry(m.r, mid + 1, r, mid + 1, R);
  }

  int bits[MAXN];
  inline int lowbit(int x) { return x & -x; }
  inline void bit_add(int v, int p, int c) {
    // printf("bit_add %d %d %d\n", v, p, c);
    for (; v <= n; v += lowbit(v)) seg_add(bits[v], 1, n, p, c);
  }
  inline int bit_qry(int v, int l, int r) {
    int c = 0;
    // printf("bit_query %d [%d, %d]", v, l, r);
    for (; v; v -= lowbit(v)) c += seg_qry(bits[v], 1, n, l, r);
    // printf(" ret = %d\n", c);
    return c;
  }

  inline void reset() {
    memset(bits, 0, sizeof(bits));
    cnt = 0;
  }
}

std::vector<int> next[MAXN];

int size[MAXN], sigma[MAXN], dfn[MAXN], dfs_clk;

void init(int x, int fa) {
  size[x] = 1;
  dfn[x] = ++dfs_clk;
  const std::vector<int> &sons = next[x];
  for (std::vector<int>::const_iterator it = sons.begin(); it != sons.end(); it++) {
    if (*it != fa) {
      init(*it, x);
      size[x] += size[*it];
    }
  }
  sigma[x] = size[x];
}

long long res;

void solve(int x, int fa) {
  const std::vector<int> &sons = next[x];
  const int m = sons.size();
  int max1 = 0, max2 = 0;
  register int s;
  for (int i = 0; i < m; i++) {
    s = sons[i];
    if (sigma[s] > max1) {
      max2 = max1;
      max1 = sigma[s];
    } else if (sigma[s] > max2) {
      max2 = sigma[s];
    }
  }
  register int ans = 0;
  for (int i = 0; i < m; i++) {
    s = sons[i];
    const int max = sigma[s] == max1 ? max2 : max1;
    const int l = std::max(2 * sigma[s] - n, 1);
    const int r = std::min(n - 2 * max, n);
    if (l > r || r <= 0) continue;
    // printf("%d >>> [%d, %d]\n", x, l, r);
    // for (int j = 1; j <= n; j++) printf("%d ", sigma[j]);
    // puts("");
    if (s != fa) {
      // dfn[s] ~ dfn[s] + size[s] - 1
      ans += DataStructure::bit_qry(dfn[s] + size[s] - 1, l, r);
      ans -= DataStructure::bit_qry(dfn[s] - 1, l, r);
    } else {
      // 1 ~ dfn[x] - 1
      // dfn[x] + size[x] ~ n
      if (dfn[x] > 1) {
        ans += DataStructure::bit_qry(dfn[x] - 1, l, r);
      }
      if (dfn[x] + size[x] <= n) {
        ans += DataStructure::bit_qry(n, l, r);
        ans -= DataStructure::bit_qry(dfn[x] + size[x] - 1, l, r);
      }
    }
  }
  // printf("%d => %d\n", x, ans);
  res += 1LL * x * ans;
  for (int i = 0; i < m; i++) {
    const int s = sons[i];
    if (s == fa) continue;
    DataStructure::bit_add(dfn[x], sigma[x], -1);
    DataStructure::bit_add(dfn[s], sigma[s], -1);
    sigma[x] -= sigma[s];
    sigma[s] += sigma[x];
    DataStructure::bit_add(dfn[x], sigma[x], 1);
    DataStructure::bit_add(dfn[s], sigma[s], 1);
    solve(s, x);
    DataStructure::bit_add(dfn[x], sigma[x], -1);
    DataStructure::bit_add(dfn[s], sigma[s], -1);
    sigma[s] -= sigma[x];
    sigma[x] += sigma[s];
    DataStructure::bit_add(dfn[x], sigma[x], 1);
    DataStructure::bit_add(dfn[s], sigma[s], 1);
  }
}

int main () {

#ifdef PROFILE
  int totalInit = 0;
  int totalSolve = 0;
  int stamp;
#endif

  freopen("centroid.in", "r", stdin);
  freopen("centroid.out", "w", stdout);
  for (int T = get_uint(); T; T--) {

#ifdef PROFILE
    stamp = clock();
#endif

    for (int i = 1; i <= n; i++) next[i].clear();
    n = get_uint();
    for (int i = 1; i < n; i++) {
      int u = get_uint(), v = get_uint();
      next[u].push_back(v);
      next[v].push_back(u);
    }
    dfs_clk = 0;
    init(1, 0);
    DataStructure::reset();

#ifdef PROFILE
    totalInit += clock() - stamp;
    stamp = clock();
#endif

    for (int i = 1; i <= n; i++) DataStructure::bit_add(dfn[i], size[i], 1);
    res = 0;
    solve(1, 0);

#ifdef PROFILE
    totalSolve += clock() - stamp;
#endif

    printf("%lld\n", res);
  }

#ifdef PROFILE
    fprintf(stderr, "Init: %lf\nSolve: %lf\n", 1. * totalInit / CLOCKS_PER_SEC, 1. * totalSolve / CLOCKS_PER_SEC);
#endif

  return 0;
}