#include <cstdio>
#include <cstring>
#include <algorithm>
#include <queue>
using namespace std;

typedef pair<int, int> pii;
typedef long long li;

const int maxn = 3e5;

int n;
vector<int> g[maxn];

int size[maxn];
int son[maxn];
int par[maxn];

void Dfs1(int u) {
  size[u] = 1;
  son[u] = -1;
  for (int i = 0; i < g[u].size(); ++i) {
    int v = g[u][i];
    if (v == par[u]) continue;
    par[v] = u;
    Dfs1(v);
    size[u] += size[v];
    if (son[u] == -1 || size[v] > size[son[u]]) son[u] = v;
  }
}

// ----------------------------------------

int bit[maxn + 1];

int Low(int i) {
  return i & -i;
}

void Add(int i, int x) {
  for (; i <= n; i += Low(i + 1)) {
    bit[i] += x;
  }
}

int Sum(int i) {
  int sum = 0;
  for (; i >= 0; i -= Low(i + 1)) {
    sum += bit[i];
  }
  return sum;
}

// ----------------------------------------

struct Query {
  int l, r, w;
};

vector<Query> q[maxn];
Query qex[maxn];

void CalcNeed(int u) {
  int p = par[u];

  vector<int> s;
  for (int i = 0; i < g[u].size(); ++i) {
    int v = g[u][i];
    if (v == p) {
      s.push_back(n - size[u]);
    } else {
      s.push_back(size[v]);
    }
  }

  int min_c = n - 1, min_i = -1, sec_c = n - 1;
  for (int i = 0; i < s.size(); ++i) {
    int c = n - 2 * s[i];
    if (c < min_c) {
      sec_c = min_c;
      min_c = c;
      min_i = i;
    } else if (c < sec_c) {
      sec_c = c;
    }
  }
  for (int i = 0; i < s.size(); ++i) {
    int c = (i == min_i ? sec_c : min_c);
    int R = min(c, n - 1);
    int L = max(2 * s[i] - n, 1);
    int v = g[u][i];
    if (L <= R) {
      if (v == p) {
        q[0].push_back((Query){L, R, u + 1});
        q[u].push_back((Query){L, R, -(u + 1)});
        qex[u] = (Query){L, R, u + 1};
      } else {
        q[v].push_back((Query){L, R, u + 1});
      }
    }
  }
}

// ----------------------------------------

li ans;

void DfsClear(int u) {
  Add(size[u], -1);
  for (int i = 0; i < g[u].size(); ++i) {
    int v = g[u][i];
    if (v == par[u]) continue;
    DfsClear(v);
  }
}

void DfsFill(int u) {
  Add(size[u], +1);
  for (int i = 0; i < g[u].size(); ++i) {
    int v = g[u][i];
    if (v == par[u]) continue;
    DfsFill(v);
  }
}

void Dfs2(int u) {
  for (int i = 0; i < g[u].size(); ++i) {
    int v = g[u][i];
    if (v == par[u] || v == son[u]) continue;
    Dfs2(v);
    DfsClear(v);
  }
  if (son[u] != -1) {
    int v = son[u];
    Dfs2(v);
  }
  for (int i = 0; i < g[u].size(); ++i) {
    int v = g[u][i];
    if (v == par[u] || v == son[u]) continue;
    DfsFill(v);
  }
  Add(size[u], +1);
  for (int i = 0; i < q[u].size(); ++i) {
    int l = q[u][i].l, r = q[u][i].r, w = q[u][i].w;
    int way = Sum(r) - Sum(l - 1);
    ans += (li)way * w;
  }
}

// ----------------------------------------

void DfsEx(int u) {
  if (u != 0) {
    int l = qex[u].l, r = qex[u].r, w = qex[u].w;
    int way = Sum(r) - Sum(l - 1);
    ans += (li)way * w;
  }
  Add(size[u], -1);
  for (int i = 0; i < g[u].size(); ++i) {
    int v = g[u][i];
    if (v == par[u]) continue;
    Add(n - size[v], +1);
    DfsEx(v);
    Add(n - size[v], -1);
  }
  Add(size[u], +1);
}

void Solve(void) {
  scanf("%d", &n);
  for (int i = 0; i < n; ++i) {
    g[i].clear();
    q[i].clear();
    qex[i] = (Query){0, 0, 0};
  }
  for (int i = 0; i < n - 1; ++i) {
    int u, v;
    scanf("%d%d", &u, &v);
    --u; --v;
    g[u].push_back(v);
    g[v].push_back(u);
  }
  par[0] = -1;
  Dfs1(0);

  for (int u = 0; u < n; ++u) {
    CalcNeed(u);
  }

  ans = 0;
  memset(bit, 0, sizeof bit);
  Dfs2(0);
  memset(bit, 0, sizeof bit);
  DfsEx(0);

  printf("%lld\n", ans);
}

int main(void) {
  freopen("centroid.in", "r", stdin);
  freopen("centroid.out", "w", stdout);
  int T;
  scanf("%d", &T);
  while (T--) Solve();
  return 0;
}
